.. highlight:: shell

============
Interactive web application
============


Launch stlearn in your local
---------------

Run the launch command in the terminal:
::

	stlearn launch

After that, you can access `https://<IP address>:5000` in your web browser.

Check the detail tutorial in this pdf file: `Link <https://github.com/BiomedicalMachineLearning/stlearn_interactive/blob/master/docs/stlearn_interactive_tutorial.pdf>`_
